# Landborn: Easy Visualization Library

Landborn is a Python visualization library designed to make it easy to generate common types of plots using matplotlib, pandas, and numpy. It simplifies the process of creating bar plots, scatter plots, and line plots with minimal code.

## Features

- **Bar Plot**: Generate vertical or horizontal bar plots.
- **Scatter Plot**: Create scatter plots with customizable colors, markers, and size.
- **Line Plot**: Plot lines with options for color, size, style, and markers.
- **Joint Plot**: Plot a scatter and line plot all in one!
- **Swarm Plot**: Plot a swarmplot to show data distribution

## Note

This is a school project and not meant for industry use.

## Installation

You can install Landborn directly from PyPI:

```bash
pip install landborn
```

## Testing

To run the tests, inside main dir, run pytest tests/tests.py